import * as vscode from 'vscode';
import * as child_process from 'child_process';

export class GitService {
    private _repoPath: string;

    constructor() {
        const workspaceFolders = vscode.workspace.workspaceFolders;
        if (!workspaceFolders || workspaceFolders.length === 0) {
            throw new Error('No workspace folder opened');
        }
        this._repoPath = workspaceFolders[0].uri.fsPath;
    }

    public async getCommits(filter: string = ''): Promise<any[]> {
        const command = `git log --oneline ${filter}`;
        return new Promise((resolve, reject) => {
            child_process.exec(command, { cwd: this._repoPath }, (error, stdout, stderr) => {
                if (error) {
                    reject(error);
                } else {
                    const commits = stdout.split('\n').map(line => {
                        const parts = line.split(' ');
                        return { hash: parts[0], message: parts.slice(1).join(' ') };
                    }).filter(commit => commit.hash);
                    resolve(commits);
                }
            });
        });
    }

    public async getCommitFiles(commit: string): Promise<string[]> {
        const command = `git show --name-only --pretty='' ${commit}`;
        return new Promise((resolve, reject) => {
            child_process.exec(command, { cwd: this._repoPath }, (error, stdout, stderr) => {
                if (error) {
                    reject(error);
                } else {
                    const files = stdout.split('\n').filter(file => file);
                    resolve(files);
                }
            });
        });
    }
}