import * as vscode from 'vscode';
import { CommitPanel } from './CommitPanel';
import { GitService } from './GitService';

export function activate(context: vscode.ExtensionContext) {
    const gitService = new GitService();

    // 创建一个TreeDataProvider实例
    const commitTreeDataProvider = new CommitTreeDataProvider();

    // 注册TreeDataProvider
    const activityBarIcon = vscode.window.registerTreeDataProvider('gitCommitFilter', commitTreeDataProvider);

    let disposable = vscode.commands.registerCommand('gitcommitfilter.showCommitPanel', () => {
        CommitPanel.show(context, gitService);
    });

    context.subscriptions.push(disposable);
    context.subscriptions.push(activityBarIcon);
}

export function deactivate() {}

// 实现TreeDataProvider接口
class CommitTreeDataProvider implements vscode.TreeDataProvider<vscode.TreeItem> {
    private _onDidChangeTreeData: vscode.EventEmitter<vscode.TreeItem | undefined | void> = new vscode.EventEmitter<vscode.TreeItem | undefined | void>();
    readonly onDidChangeTreeData: vscode.Event<vscode.TreeItem | undefined | void> = this._onDidChangeTreeData.event;

    constructor() {}

    refresh(): void {
        this._onDidChangeTreeData.fire();
    }

    getTreeItem(element: vscode.TreeItem): vscode.TreeItem {
        return element;
    }

    getChildren(element?: vscode.TreeItem): vscode.ProviderResult<vscode.TreeItem[]> {
        if (element) {
            return [];
        }
        const icon = new vscode.TreeItem('Git Commits', vscode.TreeItemCollapsibleState.None);
        icon.command = { command: 'gitcommitfilter.showCommitPanel', title: 'Show Git Commits' };
        icon.iconPath = new vscode.ThemeIcon('git-commit');
        return [icon];
    }
}
